@@ -248,6 +248,19 @@ void dc_lex_token(BcLex *l) {
 			break;
 		}
 
+		case 'g':
+		{
+			c2 = l->buf[l->i];
+
+			if (c2 == 'l') l->t = BC_LEX_KW_LINE_LENGTH;
+			else if (c2 == 'z') l->t = BC_LEX_KW_LEADING_ZERO;
+			else bc_lex_invalidChar(l, c2);
+
+			l->i += 1;
+
+			break;
+		}
+
 		case '[':
 		{
 			dc_lex_string(l);
